==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/eks_node_group/EksNodeGroupRemoteAccess.java <==
package com.hashicorp.cdktf.providers.aws.eks_node_group;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:53.837Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.eksNodeGroup.EksNodeGroupRemoteAccess")
@software.amazon.jsii.Jsii.Proxy(EksNodeGroupRemoteAccess.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface EksNodeGroupRemoteAccess extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#ec2_ssh_key EksNodeGroup#ec2_ssh_key}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getEc2SshKey() {
        return null;
    }

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#source_security_group_ids EksNodeGroup#source_security_group_ids}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getSourceSecurityGroupIds() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link EksNodeGroupRemoteAccess}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EksNodeGroupRemoteAccess}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<EksNodeGroupRemoteAccess> {
        java.lang.String ec2SshKey;
        java.util.List<java.lang.String> sourceSecurityGroupIds;

        /**
         * Sets the value of {@link EksNodeGroupRemoteAccess#getEc2SshKey}
         * @param ec2SshKey Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#ec2_ssh_key EksNodeGroup#ec2_ssh_key}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ec2SshKey(java.lang.String ec2SshKey) {
            this.ec2SshKey = ec2SshKey;
            return this;
        }

        /**
         * Sets the value of {@link EksNodeGroupRemoteAccess#getSourceSecurityGroupIds}
         * @param sourceSecurityGroupIds Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#source_security_group_ids EksNodeGroup#source_security_group_ids}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceSecurityGroupIds(java.util.List<java.lang.String> sourceSecurityGroupIds) {
            this.sourceSecurityGroupIds = sourceSecurityGroupIds;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EksNodeGroupRemoteAccess}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public EksNodeGroupRemoteAccess build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link EksNodeGroupRemoteAccess}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EksNodeGroupRemoteAccess {
        private final java.lang.String ec2SshKey;
        private final java.util.List<java.lang.String> sourceSecurityGroupIds;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ec2SshKey = software.amazon.jsii.Kernel.get(this, "ec2SshKey", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.sourceSecurityGroupIds = software.amazon.jsii.Kernel.get(this, "sourceSecurityGroupIds", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ec2SshKey = builder.ec2SshKey;
            this.sourceSecurityGroupIds = builder.sourceSecurityGroupIds;
        }

        @Override
        public final java.lang.String getEc2SshKey() {
            return this.ec2SshKey;
        }

        @Override
        public final java.util.List<java.lang.String> getSourceSecurityGroupIds() {
            return this.sourceSecurityGroupIds;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getEc2SshKey() != null) {
                data.set("ec2SshKey", om.valueToTree(this.getEc2SshKey()));
            }
            if (this.getSourceSecurityGroupIds() != null) {
                data.set("sourceSecurityGroupIds", om.valueToTree(this.getSourceSecurityGroupIds()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.eksNodeGroup.EksNodeGroupRemoteAccess"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EksNodeGroupRemoteAccess.Jsii$Proxy that = (EksNodeGroupRemoteAccess.Jsii$Proxy) o;

            if (this.ec2SshKey != null ? !this.ec2SshKey.equals(that.ec2SshKey) : that.ec2SshKey != null) return false;
            return this.sourceSecurityGroupIds != null ? this.sourceSecurityGroupIds.equals(that.sourceSecurityGroupIds) : that.sourceSecurityGroupIds == null;
        }

        @Override
        public final int hashCode() {
            int result = this.ec2SshKey != null ? this.ec2SshKey.hashCode() : 0;
            result = 31 * result + (this.sourceSecurityGroupIds != null ? this.sourceSecurityGroupIds.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/eks_node_group/EksNodeGroupRemoteAccess.java <==
package com.hashicorp.cdktf.providers.aws.eks_node_group;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:09.699Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.eksNodeGroup.EksNodeGroupRemoteAccess")
@software.amazon.jsii.Jsii.Proxy(EksNodeGroupRemoteAccess.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface EksNodeGroupRemoteAccess extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/eks_node_group#ec2_ssh_key EksNodeGroup#ec2_ssh_key}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getEc2SshKey() {
        return null;
    }

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/eks_node_group#source_security_group_ids EksNodeGroup#source_security_group_ids}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getSourceSecurityGroupIds() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link EksNodeGroupRemoteAccess}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EksNodeGroupRemoteAccess}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<EksNodeGroupRemoteAccess> {
        java.lang.String ec2SshKey;
        java.util.List<java.lang.String> sourceSecurityGroupIds;

        /**
         * Sets the value of {@link EksNodeGroupRemoteAccess#getEc2SshKey}
         * @param ec2SshKey Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/eks_node_group#ec2_ssh_key EksNodeGroup#ec2_ssh_key}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ec2SshKey(java.lang.String ec2SshKey) {
            this.ec2SshKey = ec2SshKey;
            return this;
        }

        /**
         * Sets the value of {@link EksNodeGroupRemoteAccess#getSourceSecurityGroupIds}
         * @param sourceSecurityGroupIds Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/eks_node_group#source_security_group_ids EksNodeGroup#source_security_group_ids}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceSecurityGroupIds(java.util.List<java.lang.String> sourceSecurityGroupIds) {
            this.sourceSecurityGroupIds = sourceSecurityGroupIds;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EksNodeGroupRemoteAccess}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public EksNodeGroupRemoteAccess build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link EksNodeGroupRemoteAccess}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EksNodeGroupRemoteAccess {
        private final java.lang.String ec2SshKey;
        private final java.util.List<java.lang.String> sourceSecurityGroupIds;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ec2SshKey = software.amazon.jsii.Kernel.get(this, "ec2SshKey", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.sourceSecurityGroupIds = software.amazon.jsii.Kernel.get(this, "sourceSecurityGroupIds", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ec2SshKey = builder.ec2SshKey;
            this.sourceSecurityGroupIds = builder.sourceSecurityGroupIds;
        }

        @Override
        public final java.lang.String getEc2SshKey() {
            return this.ec2SshKey;
        }

        @Override
        public final java.util.List<java.lang.String> getSourceSecurityGroupIds() {
            return this.sourceSecurityGroupIds;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getEc2SshKey() != null) {
                data.set("ec2SshKey", om.valueToTree(this.getEc2SshKey()));
            }
            if (this.getSourceSecurityGroupIds() != null) {
                data.set("sourceSecurityGroupIds", om.valueToTree(this.getSourceSecurityGroupIds()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.eksNodeGroup.EksNodeGroupRemoteAccess"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EksNodeGroupRemoteAccess.Jsii$Proxy that = (EksNodeGroupRemoteAccess.Jsii$Proxy) o;

            if (this.ec2SshKey != null ? !this.ec2SshKey.equals(that.ec2SshKey) : that.ec2SshKey != null) return false;
            return this.sourceSecurityGroupIds != null ? this.sourceSecurityGroupIds.equals(that.sourceSecurityGroupIds) : that.sourceSecurityGroupIds == null;
        }

        @Override
        public final int hashCode() {
            int result = this.ec2SshKey != null ? this.ec2SshKey.hashCode() : 0;
            result = 31 * result + (this.sourceSecurityGroupIds != null ? this.sourceSecurityGroupIds.hashCode() : 0);
            return result;
        }
    }
}
